'''
This script computes volume averaged position and surface area and saves these
integrals for each time step.

Tracing was used to capture the script but it has been heavily edited. Version
from which the trace was collected is 5.11.2.
'''
# trace generated using paraview version 5.11.2
#import paraview
#paraview.compatibility.major = 5
#paraview.compatibility.minor = 11

# Adding current directory to PYTHONPATH to allow modules.
import os
current_directory = os.path.dirname(os.path.abspath(__file__))
#### Utilities
from time import perf_counter
from paraview.simple import (
    UpdatePipeline,
    GetActiveViewOrCreate,
    GetAnimationScene,
    OpenFOAMReader,
    Show,
    SaveData)
# Filters
from paraview.simple import (
    Connectivity,
    MergeBlocks,
    IntegrateVariables,
    Threshold)


# create a new 'OpenFOAMReader'
reader = OpenFOAMReader(
    registrationName='My case',
    FileName=f'{current_directory}/open.foam')
reader.MeshRegions = ['internalMesh']
reader.CellArrays = ['alpha.water']
reader.Createcelltopointfiltereddata = 0
reader.CaseType = 'Decomposed Case'

merge_blocks = MergeBlocks(
    registrationName=f'Merge blocks',
    Input=reader)

# get animation scene
animation_scene = GetAnimationScene()
# update animation scene based on data timesteps
animation_scene.UpdateAnimationUsingDataTimeSteps()
time0 = animation_scene.TimeKeeper.TimestepValues[0]

threshold = Threshold(registrationName=f'Liquid only', Input=merge_blocks)
threshold.LowerThreshold = 0.5
threshold.UpperThreshold = 1.0
threshold.Scalars = ['CELLS', 'alpha.water']
UpdatePipeline(time=time0, proxy=threshold)

connectivity = Connectivity(
    registrationName=f'Largest liquid chunk only',
    Input=threshold)
connectivity.ExtractionMode = 'Extract Largest Region'
UpdatePipeline(time=time0, proxy=connectivity)

integrate_variables = IntegrateVariables(
    registrationName=f'Integral',
    Input=connectivity)
UpdatePipeline(time=time0, proxy=integrate_variables)

SaveData(
     'output.csv',
     proxy=integrate_variables,
     ChooseArraysToWrite=1,
     CellDataArrays=['Volume'],
     FieldAssociation='Cell Data',
     WriteTimeSteps=1,
     AddTimeStep=1,
     AddTime=1)
